==> growingio-graphql-javasdk_2.12-0.0.1-sources.jar: io/growing/graphql/model/RemoveCategoryResourcesMutationRequest.java <==
package io.growing.graphql.model;

import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLOperation;
import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLOperationRequest;
import java.util.LinkedHashMap;
import java.util.Map;
import java.util.Objects;

@javax.annotation.Generated(
    value = "com.kobylynskyi.graphql.codegen.GraphQLCodegen",
    date = "2020-12-22T15:45:58+0800"
)
public class RemoveCategoryResourcesMutationRequest implements GraphQLOperationRequest {

    private static final GraphQLOperation OPERATION_TYPE = GraphQLOperation.MUTATION;
    private static final String OPERATION_NAME = "removeCategoryResources";

    private Map<String, Object> input = new LinkedHashMap<>();

    public RemoveCategoryResourcesMutationRequest() {
    }

    public void setCategoryResources(java.util.List<CategoryResourceInputDto> categoryResources) {
        this.input.put("categoryResources", categoryResources);
    }

    @Override
    public GraphQLOperation getOperationType() {
        return OPERATION_TYPE;
    }

    @Override
    public String getOperationName() {
        return OPERATION_NAME;
    }

    @Override
    public Map<String, Object> getInput() {
        return input;
    }

    @Override
    public String toString() {
        return Objects.toString(input);
    }

    public static class Builder {

        private java.util.List<CategoryResourceInputDto> categoryResources;

        public Builder() {
        }

        public Builder setCategoryResources(java.util.List<CategoryResourceInputDto> categoryResources) {
            this.categoryResources = categoryResources;
            return this;
        }


        public RemoveCategoryResourcesMutationRequest build() {
            RemoveCategoryResourcesMutationRequest obj = new RemoveCategoryResourcesMutationRequest();
            obj.setCategoryResources(categoryResources);
            return obj;
        }

    }
}

==> growingio-graphql-javasdk_2.12-0.0.2-sources.jar: io/growing/graphql/model/RemoveCategoryResourcesMutationRequest.java <==
package io.growing.graphql.model;

import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLOperation;
import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLOperationRequest;
import java.util.LinkedHashMap;
import java.util.Map;
import java.util.Objects;

/**
 * 删除分类内资源
 */
@javax.annotation.processing.Generated(
    value = "com.kobylynskyi.graphql.codegen.GraphQLCodegen",
    date = "2021-05-27T14:30:17+0800"
)
public class RemoveCategoryResourcesMutationRequest implements GraphQLOperationRequest {

    private static final GraphQLOperation OPERATION_TYPE = GraphQLOperation.MUTATION;
    private static final String OPERATION_NAME = "removeCategoryResources";

    private Map<String, Object> input = new LinkedHashMap<>();

    public RemoveCategoryResourcesMutationRequest() {
    }

    public void setCategoryResources(java.util.List<CategoryResourceInputDto> categoryResources) {
        this.input.put("categoryResources", categoryResources);
    }

    @Override
    public GraphQLOperation getOperationType() {
        return OPERATION_TYPE;
    }

    @Override
    public String getOperationName() {
        return OPERATION_NAME;
    }

    @Override
    public Map<String, Object> getInput() {
        return input;
    }

    @Override
    public String toString() {
        return Objects.toString(input);
    }

    public static class Builder {

        private java.util.List<CategoryResourceInputDto> categoryResources;

        public Builder() {
        }

        public Builder setCategoryResources(java.util.List<CategoryResourceInputDto> categoryResources) {
            this.categoryResources = categoryResources;
            return this;
        }


        public RemoveCategoryResourcesMutationRequest build() {
            RemoveCategoryResourcesMutationRequest obj = new RemoveCategoryResourcesMutationRequest();
            obj.setCategoryResources(categoryResources);
            return obj;
        }

    }
}
